@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "قرارها",
     "Schedule appointment \"%s\"" : "Schedule appointment \"%s\"",
     "Schedule an appointment" : "Schedule an appointment",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Prepare for %s" : "Prepare for %s",
     "Follow up for %s" : "Follow up for %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Your appointment \"%s\" with %s needs confirmation",
@@ -60,6 +59,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Appointment link could not be copied to clipboard",
     "Preview" : "پیش‌نمایش",
     "Copy link" : "کپی کردن لینک",
+    "Duplicate" : "Duplicate",
     "Edit" : "ویرایش",
     "Delete" : "حذف",
     "Create new" : "ایجاد جدید",
@@ -193,6 +193,7 @@ OC.L10N.register(
     "Public – shown on the profile page" : "عمومی – در صفحهٔ نمایه نشان داده می‌شود",
     "Private – only accessible via secret link" : "Private – only accessible via secret link",
     "Update" : "به روز رسانی",
+    "(copy)" : "(کپی)",
     "Appointment name" : "Appointment name",
     "Location" : "مکان",
     "Create a Talk room" : "ایجاد اتاق گفتگو",
@@ -287,6 +288,7 @@ OC.L10N.register(
     "Accept" : "تایید",
     "Decline" : "کاهش می یابد",
     "Tentative" : "آزمایشی",
+    "Copied to clipboard" : "در حافظه رونویسی شد",
     "No attendees yet" : "هنوز هیچ حضوری وجود ندارد",
     "Attendees" : "شرکت کنندگان",
     "Remove group" : "برداشتن گروه",
@@ -389,7 +391,6 @@ OC.L10N.register(
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue.",
     "Edit event" : "ویرایش رویداد",
     "Event does not exist" : "رویداد وجود ندارد",
-    "Duplicate" : "Duplicate",
     "Delete this occurrence" : "این رخداد را حذف کنید",
     "Delete this and all future" : "این و همه آینده را حذف کنید",
     "All day" : "تمام روز",
@@ -493,6 +494,7 @@ OC.L10N.register(
     "This is an event reminder." : "This is an event reminder.",
     "Appointment not found" : "Appointment not found",
     "User not found" : "کاربر یافت نشد",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "مخفی",
     "can edit" : "می توان ویرایش کرد",
     "Calendar name …" : "نام تقویم …",
