@@ -21,7 +21,7 @@ OC.L10N.register(
     "Appointments" : "Tapaamiset",
     "Schedule appointment \"%s\"" : "Ajoita tapaaminen \"%s\"",
     "Schedule an appointment" : "Ajoita tapaaminen",
-    "%1$s - %2$s" : "%1$s - %2$s",
+    "Appointment Description:" : "Tapaamisen kuvaus:",
     "Prepare for %s" : "Valmistaudu tapahtumaan \"%s\"",
     "Your appointment \"%s\" with %s needs confirmation" : "Tapaaminen \"%s\"  henkilön %s kanssa vaatii vahvistamisen",
     "Dear %s, please confirm your booking" : "%s, ole hyvä ja vahvista varauksesi",
@@ -44,9 +44,11 @@ OC.L10N.register(
     "Dear %s, a proposed meeting has been updated" : "%s, ehdotettu kokous on päivitetty",
     "Dear %s, a proposed meeting has been cancelled" : "%s, ehdotettu kokous on peruttu",
     "Location:" : "Sijainti:",
+    "%1$s minutes" : "%1$s minuuttia",
     "Duration:" : "Kesto:",
     "Dates:" : "Päivät:",
     "Respond" : "Vastaa",
+    "[Proposed] %1$s" : "[Ehdotettu] %1$s",
     "A Calendar app for Nextcloud" : "Kalenterisovellus Nextcloudille",
     "Previous day" : "Edellinen päivä",
     "Previous week" : "Edellinen viikko",
@@ -146,6 +148,8 @@ OC.L10N.register(
     "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
     "No users or groups" : "Ei käyttäjiä tai ryhmiä",
     "Failed to save calendar name and color" : "Kalenterin nimen ja värin tallentaminen epäonnistui",
+    "Calendar name …" : "Kalenterin nimi …",
+    "Never show me as busy (set this calendar to transparent)" : "Älä ikinä näytä minua varattuna (aseta tämä kalenteri läpinäkyväksi)",
     "Share calendar" : "Jaa kalenteri",
     "Unshare from me" : "Lopeta jako minulle",
     "Save" : "Tallenna",
@@ -200,14 +204,22 @@ OC.L10N.register(
     "At event start" : "Tapahtuman alkaessa",
     "No reminder" : "Ei muistutusta",
     "Failed to save default calendar" : "Oletuskalenterin tallentaminen epäonnistui",
-    "CalDAV link copied to clipboard." : "CalDAV-linkki kopioitu leikepöydälle.",
-    "CalDAV link could not be copied to clipboard." : "CalDAV-linkkiä ei voitu kopioida leikepöydälle.",
     "General" : "Yleiset",
-    "Copy iOS/macOS CalDAV address" : "Kopioi iOS:in/macOS:n CalDAV-osoite",
+    "Availability settings" : "Saatavuuden asetukset",
+    "CalDAV" : "CalDAV",
+    "Access Nextcloud calendars from other apps and devices" : "Käytä Nextcloud-kalentereita muista sovelluksista ja laitteilta",
+    "CalDAV URL" : "CalDAV:in URL-osoite",
+    "Server Address for iOS and macOS" : "Palvelinosoite iOS:lle ja macOS:lle",
     "Appearance" : "Ulkoasu",
-    "Default calendar for incoming invitations" : "Oletuskalenteri saapuville kutsuille",
+    "Birthday calendar" : "Syntymäpäiväkalenteri",
+    "Tasks in calendar" : "Tehtävät kalenterissa",
+    "Weekends" : "Viikonloput",
+    "Week numbers" : "Viikkonumerot",
+    "Limit number of events shown in Month view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää",
+    "Editing" : "Muokkaaminen",
     "Default reminder" : "Oletusmuistutus",
-    "Keyboard shortcuts" : "Pikanäppäimet",
+    "Simple event editor" : "Yksinkertainen tapahtumamuokkain",
+    "Files" : "Tiedostot",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuutti","{duration} minuuttia"],
     "0 minutes" : "0 minuuttia",
     "_{duration} hour_::_{duration} hours_" : ["{duration} tunti","{duration} tuntia"],
@@ -222,6 +234,7 @@ OC.L10N.register(
     "Create appointment schedule" : "Luo tapaamisaikataulu",
     "Edit appointment schedule" : "Muokkaa tapaamisaikataulua",
     "Update" : "Päivitä",
+    "(copy)" : "(kopioi)",
     "Appointment name" : "Tapaamisen nimi",
     "Location" : "Sijainti",
     "Create a Talk room" : "Luo Talk-huone",
@@ -263,13 +276,16 @@ OC.L10N.register(
     "Conversation does not have a valid URL." : "Keskustelulla ei ole kelvollista URL-osoitetta.",
     "Successfully added Talk conversation link to location." : "Talk-keskustelulinkki lisätty sijaintiin.",
     "Successfully added Talk conversation link to description." : "Talk-keskustelulinkki lisätty kuvaukseen.",
+    "Talk conversation for event" : "Tapahtuman Talk-keskustelu",
     "Error creating Talk conversation" : "Virhe luotaessa Talk-keskustelua",
     "Select a Talk Room" : "Valitse Talk-huone",
-    "Add Talk conversation" : "Lisää Talk-keskustelu",
     "Fetching Talk rooms…" : "Noudetaan Talk-huoneita…",
     "No Talk room available" : "Talk-huonetta ei ole käytettävissä",
-    "Create a new public conversation" : "Luo uusi julkinen keskustelu",
+    "Select existing conversation" : "Valitse olemassa oleva keskustelu",
     "Select conversation" : "Valitse keskustelu",
+    "Or create a new conversation" : "Tai luo uusi keskustelu",
+    "Create public conversation" : "Luo julkinen keskustelu",
+    "Create private conversation" : "Luo yksityinen keskustelu",
     "on" : "päivä",
     "at" : "kellonaika",
     "before at" : "ennen",
@@ -292,7 +308,6 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Valitse tiedosto, joka jaetaan linkkinä",
     "Attachment {name} already exist!" : "Liite {name} on jo olemassa!",
     "Could not upload attachment(s)" : "Liitteiden lähetys epäonnistui",
-    "You are about to download a file. Please check the file name before opening it. Are you sure to proceed?" : "Olet aikeissa ladata tiedoston. Tarkista tiedoston nimi ennen sen avaamista. Haluatko jatkaa?",
     "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Olet aikeissa siirtyä kohteeseen {host}. Haluatko varmasti jatkaa? Linkki: {link}",
     "Proceed" : "Jatka",
     "No attachments" : "Ei liitteitä",
@@ -330,6 +345,7 @@ OC.L10N.register(
     "Legend" : "Selite",
     "Out of office" : "Ulkona toimistolta",
     "Attendees:" : "Osallistujat:",
+    "local time" : "paikallinen aika",
     "Done" : "Valmis",
     "Search room" : "Etsi huonetta",
     "Room name" : "Huoneen nimi",
@@ -348,9 +364,8 @@ OC.L10N.register(
     "Accept" : "Hyväksy",
     "Decline" : "Kieltäydy",
     "Tentative" : "Alustava",
+    "Copied to clipboard" : "Kopioitu leikepöydälle",
     "No attendees yet" : "Ei vielä osallistujia",
-    "Successfully appended link to talk room to description." : "Linkki Talk-huoneeseen lisättiin onnistuneesti kuvaukseen.",
-    "Error creating Talk room" : "Virhe luotaessa Talk-huonetta",
     "Attendees" : "Osallistujat",
     "Remove group" : "Poista ryhmä",
     "Remove attendee" : "Poista osallistuja",
@@ -470,6 +485,7 @@ OC.L10N.register(
     "Delete this occurrence" : "Poista tämä esiintymä",
     "Delete this and all future" : "Poista tämä ja kaikki tulevat",
     "All day" : "Koko päivä",
+    "Add Talk conversation" : "Lisää Talk-keskustelu",
     "Managing shared access" : "Jaetun pääsyn hallinta",
     "Deny access" : "Estä pääsy",
     "Invite" : "Kutsu",
@@ -500,6 +516,8 @@ OC.L10N.register(
     "90 min" : "90 min",
     "Participants" : "Osallistujat",
     "Selected times" : "Valitut ajat",
+    "Less days" : "Vähemmän päiviä",
+    "More days" : "Enemmän päiviä",
     "Loading meeting proposal" : "Ladataan kokousehdotusta",
     "No meeting proposal found" : "Kokousehdotusta ei löytynyt",
     "Thank you for your response!" : "Kiitos vastauksestasi!",
@@ -560,6 +578,7 @@ OC.L10N.register(
     "last" : "viimeinen",
     "Untitled task" : "Nimetön tehtävä",
     "Please ask your administrator to enable the Tasks App." : "Pyydä järjestelmänvalvojaa ottamaan Tasks-sovellus käyttöön",
+    "You are not allowed to edit this event as an attendee." : "Sinulla ei ole oikeutta muokata tätä tapahtumaa osallistujan roolissa.",
     "W" : "Vko",
     "%n more" : "%n lisää",
     "No events to display" : "Ei tapahtumia näytettäväksi",
@@ -602,18 +621,20 @@ OC.L10N.register(
     "Attachment {fileName} added!" : "Liite {fileName} lisätty!",
     "An error occurred during uploading file {fileName}" : "Tiedostoa {fileName} lähettäessä tapahtui virhe",
     "An error occurred during getting file information" : "Tiedostojen tietoja noutaessa tapahtui virhe",
-    "Talk conversation for event" : "Tapahtuman Talk-keskustelu",
     "An error occurred, unable to delete the calendar." : "Tapahtui virhe, kalenteria ei voitu poistaa.",
     "Imported {filename}" : "Tuotiin {filename}",
     "This is an event reminder." : "Tämä on tapahtuman muistutus.",
     "Appointment not found" : "Tapaamista ei löydy",
     "User not found" : "Käyttäjää ei löydy",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "Piilotettu",
     "can edit" : "voi muokata",
     "Calendar name …" : "Kalenterin nimi…",
     "Default attachments location" : "Liitteiden oletussijainti",
     "Automatic ({detected})" : "Automaattinen ({detected})",
     "Shortcut overview" : "Pikakuvakenäkymä",
+    "CalDAV link copied to clipboard." : "CalDAV-linkki kopioitu leikepöydälle.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV-linkkiä ei voitu kopioida leikepöydälle.",
     "Enable birthday calendar" : "Käytä syntymäpäiväkalenteria",
     "Show tasks in calendar" : "Näytä tehtävät kalenterissa",
     "Enable simplified editor" : "Käytä yksinkertaistettua muokkainta",
@@ -621,12 +642,15 @@ OC.L10N.register(
     "Show weekends" : "Näytä viikonloput",
     "Show week numbers" : "Näytä viikkonumerot",
     "Time increments" : "Aikavälit",
+    "Default calendar for incoming invitations" : "Oletuskalenteri saapuville kutsuille",
     "Copy primary CalDAV address" : "Kopioi ensisijainen CalDAV-osoite",
+    "Copy iOS/macOS CalDAV address" : "Kopioi iOS:in/macOS:n CalDAV-osoite",
     "Personal availability settings" : "Henkilökohtaiset saatavuusasetukset",
     "Show keyboard shortcuts" : "Näytä pikanäppäimet",
+    "Create a new public conversation" : "Luo uusi julkinen keskustelu",
     "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} kutsuttu, {confirmedCount} vahvistettu",
-    "The visibility of this event in shared calendars." : "Tämän tapahtuman näkyvyys jaetuissa kalentereissa.",
-    "View options" : "Näkymävalinnat",
-    "Limit number of events shown in month view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää"
+    "Successfully appended link to talk room to description." : "Linkki Talk-huoneeseen lisättiin onnistuneesti kuvaukseen.",
+    "Error creating Talk room" : "Virhe luotaessa Talk-huonetta",
+    "The visibility of this event in shared calendars." : "Tämän tapahtuman näkyvyys jaetuissa kalentereissa."
 },
 "nplurals=2; plural=(n != 1);");
