@@ -124,14 +124,11 @@ OC.L10N.register(
     "Show shortcuts" : "Prikaži prečace",
     "or" : "ili",
     "No reminder" : "Nema podsjetnika",
-    "CalDAV link copied to clipboard." : "Poveznica kalendara CalDAV kopirana je u međuspremnik.",
-    "CalDAV link could not be copied to clipboard." : "Poveznica kalendara CalDAV nije kopirana u međuspremnik.",
     "General" : "Općenito",
-    "Copy iOS/macOS CalDAV address" : "Kopiraj iOS/macOS CalDAV adresu",
     "Appearance" : "Izgled",
     "Editing" : "Uređivanje",
     "Default reminder" : "Zadani podsjetnik",
-    "Keyboard shortcuts" : "Tipkovni prečaci",
+    "Files" : "Datoteke",
     "Update" : "Ažuriraj",
     "Location" : "Lokacija",
     "Description" : "Opis",
@@ -185,9 +182,8 @@ OC.L10N.register(
     "Accept" : "Prihvati",
     "Decline" : "Odbij",
     "Tentative" : "Uvjetno",
+    "Copied to clipboard" : "Kopirano u međuspremnik",
     "No attendees yet" : "Još nema sudionika",
-    "Successfully appended link to talk room to description." : "Uspješno dodana poveznica na Talk sobu u opis.",
-    "Error creating Talk room" : "Pogreška pri stvaranju Talk sobe",
     "Attendees" : "Sudionici",
     "Remove group" : "Ukloni grupu",
     "Remove attendee" : "Ukloni sudionika",
@@ -367,6 +363,8 @@ OC.L10N.register(
     "can edit" : "uređivanje moguće",
     "Automatic ({detected})" : "Automatsko ({detected})",
     "Shortcut overview" : "Pregled prečaca",
+    "CalDAV link copied to clipboard." : "Poveznica kalendara CalDAV kopirana je u međuspremnik.",
+    "CalDAV link could not be copied to clipboard." : "Poveznica kalendara CalDAV nije kopirana u međuspremnik.",
     "Enable birthday calendar" : "Omogući kalendar rođendana",
     "Show tasks in calendar" : "Prikaži zadatke u kalendaru",
     "Enable simplified editor" : "Omogući jednostavan uređivač",
@@ -374,7 +372,10 @@ OC.L10N.register(
     "Show week numbers" : "Prikaži brojeve tjedana",
     "Time increments" : "Vremenski prirasti",
     "Copy primary CalDAV address" : "Kopiraj primarnu CalDAV adresu",
+    "Copy iOS/macOS CalDAV address" : "Kopiraj iOS/macOS CalDAV adresu",
     "Show keyboard shortcuts" : "Prikaži tipkovne prečace",
+    "Successfully appended link to talk room to description." : "Uspješno dodana poveznica na Talk sobu u opis.",
+    "Error creating Talk room" : "Pogreška pri stvaranju Talk sobe",
     "The visibility of this event in shared calendars." : "Vidljivost ovog događaja u dijeljenim kalendarima."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
