@@ -26,6 +26,7 @@ OC.L10N.register(
     "Your appointment \"%s\" with %s needs confirmation" : "Janji temu Anda \"%s\" dengan %s membutuhkan konfirmasi ",
     "Dear %s, please confirm your booking" : "Kepada %s, mohon konfirmasi pemesanan Anda",
     "Confirm" : "Konfirmasi",
+    "Description:" : "Deskripsi:",
     "This confirmation link expires in %s hours." : "Tautan konfirmasi ini akan kedaluwarsa dalam %s jam.",
     "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Jika Anda ingin membatalkan janji temu, mohon hubungi penyelenggara Anda dengan membalas email ini atau mengunjungi halaman profil mereka",
     "Your appointment \"%s\" with %s has been accepted" : "Janji temu \"%s\" dengan %stelah diterima",
@@ -158,13 +159,16 @@ OC.L10N.register(
     "General" : "Umum",
     "Appearance" : "Tampilan",
     "Editing" : "Pengeditan",
+    "Files" : "File",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} menit"],
     "_{duration} hour_::_{duration} hours_" : ["{duration} jam"],
     "To configure appointments, add your email address in personal settings." : "Untuk mengonfigurasi janji temu, tambahkan alamat email Anda di pengaturan pribadi.",
     "Update" : "Perbarui",
+    "(copy)" : "(salinan)",
     "Location" : "Lokasi",
     "Description" : "Deskrisi",
     "to" : "untuk",
+    "Delete slot" : "Hapus slot",
     "Add" : "Masukkan",
     "Monday" : "Senin",
     "Tuesday" : "Selasa",
@@ -173,9 +177,11 @@ OC.L10N.register(
     "Friday" : "Jumat",
     "Saturday" : "Sabtu",
     "Sunday" : "Minggu",
+    "Weekdays" : "Hari kerja",
     "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Kami telah mengirim email dengan detailnya. Mohon konfirmasikan janji temu Anda menggunakan tautan dalam email tersebut. Anda dapat menutup halaman ini sekarang.",
     "Your email address" : "Alamat email Anda",
     "Could not book the appointment. Please try again later or contact the organizer." : "Tidak dapat memesan janji temu. Mohon coba lagi nanti atau hubungi penyelenggara.",
+    "Back" : "Kembali",
     "on" : "pada",
     "at" : "di",
     "Notification" : "Notifikasi",
@@ -197,6 +203,7 @@ OC.L10N.register(
     "Not available" : "Tidak tersedia",
     "Availability of attendees, resources and rooms" : "Ketersediaan peserta, sumber daya, dan ruangan",
     "Out of office" : "Keluar kantor",
+    "Attendees:" : "Peserta:",
     "Done" : "Selesai",
     "Room name" : "Nama ruang",
     "Free" : "Luang",
@@ -212,6 +219,7 @@ OC.L10N.register(
     "Accept" : "Terima",
     "Decline" : "Tolak",
     "Tentative" : "Tentatif",
+    "Copied to clipboard" : "Disalin ke papan klip",
     "No attendees yet" : "Belum ada peserta",
     "Attendees" : "Peserta",
     "Remove group" : "Hapus grup",
@@ -267,8 +275,10 @@ OC.L10N.register(
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Zona waktu Anda yang terkonfigurasi ({timezoneId}) tidak ditemukan. Kembali ke UTC.\nHarap ubah zona waktu Anda di pengaturan dan laporkan masalah ini.",
     "Edit event" : "Sunting agenda",
     "All day" : "Sepanjang hari",
+    "Invite" : "Undangan",
     "Untitled event" : "Acara tanpa judul",
     "Close" : "Tutup",
+    "Submit" : "Kirim",
     "Subscribe to {name}" : "Berlangganan ke {name}",
     "Anniversary" : "Hari jadi",
     "Appointment" : "Janji",
