@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "Stefnumót",
     "Schedule appointment \"%s\"" : "Setja stefnumótið \"%s\" á dagskrá",
     "Schedule an appointment" : "Setja stefnumót á dagskrá",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Prepare for %s" : "Undirbúa fyrir %s",
     "Follow up for %s" : "Fylgja eftir %s",
     "Your appointment \"%s\" with %s needs confirmation" : "\"%s\" stefnumótið þitt við %s krefst staðfestingar",
@@ -63,6 +62,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Ekki var hægt að afrita stefnumótstengil á klippispjald",
     "Preview" : "Forskoðun",
     "Copy link" : "Afrita tengil",
+    "Duplicate" : "Tvítaka",
     "Edit" : "Breyta",
     "Delete" : "Eyða",
     "Appointment schedules" : "Dagskrá stefnumóta",
@@ -187,15 +187,11 @@ OC.L10N.register(
     "At event start" : "Við upphaf atburðar",
     "No reminder" : "Engin áminning",
     "Failed to save default calendar" : "Mistókst að vista sjálfgefið dagatal",
-    "CalDAV link copied to clipboard." : "CalDAV-tengill afritaður á klippispjald.",
-    "CalDAV link could not be copied to clipboard." : "Ekki var hægt að afrita CalDAV-tengil á klippispjald.",
     "General" : "Almennt",
-    "Copy iOS/macOS CalDAV address" : "Afrita iOS/macOS CalDAV-vistfang ",
     "Appearance" : "Útlit",
     "Editing" : "Breytingar",
-    "Default calendar for incoming invitations" : "Sjálfgefið dagatal fyrir boð sem berast",
     "Default reminder" : "Sjálfgefin áminning",
-    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
+    "Files" : "Skráaforrit",
     "Appointment schedule successfully created" : "Tókst að útbúa dagskrá stefnumóta",
     "Appointment schedule successfully updated" : "Tókst að uppfæra dagskrá stefnumóta",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} mínúta","{duration} mínútur"],
@@ -212,6 +208,7 @@ OC.L10N.register(
     "Create appointment schedule" : "Útbúa dagskrá stefnumóta",
     "Edit appointment schedule" : "Breyta dagskrá stefnumóta",
     "Update" : "Uppfæra",
+    "(copy)" : "(afrita)",
     "Appointment name" : "Heiti stefnumóts",
     "Location" : "Staðsetning",
     "Create a Talk room" : "Búa til spjallrás",
@@ -255,9 +252,9 @@ OC.L10N.register(
     "Successfully added Talk conversation link to location." : "Tókst að bæta tengli á samtal á staðsetningu.",
     "Successfully added Talk conversation link to description." : "Tókst að bæta tengli á samtal á lýsingu.",
     "Failed to apply Talk room." : "Mistókst að virkja spjallrás.",
+    "Talk conversation for event" : "Samtal fyrir atburð",
     "Error creating Talk conversation" : "Mistókst að útbúa samtal",
     "Select a Talk Room" : "Veldu spjallrás",
-    "Add Talk conversation" : "Bæta við samtali á spjallrás",
     "Fetching Talk rooms…" : "Sæki spjallrásir…",
     "No Talk room available" : "Engin spjallrás tiltæk",
     "Select conversation" : "Veldu samtal",
@@ -335,10 +332,8 @@ OC.L10N.register(
     "Accept" : "Samþykkja",
     "Decline" : "Hafna",
     "Tentative" : "Með fyrirvara",
+    "Copied to clipboard" : "Afritað á klippispjald",
     "No attendees yet" : "Engir þátttakendur ennþá",
-    "Successfully appended link to talk room to location." : "Tókst að bæta tengli á spjallsvæði við staðsetningu.",
-    "Successfully appended link to talk room to description." : "Tókst að bæta tengli á spjallsvæði við lýsingu.",
-    "Error creating Talk room" : "Villa við að búa til spjallsvæði.",
     "Attendees" : "Þátttakendur",
     "Remove group" : "Fjarlægja hóp",
     "Remove attendee" : "Fjarlægja þátttakanda",
@@ -452,10 +447,10 @@ OC.L10N.register(
     "Availability of {displayName}" : "Lausir tímar hjá {displayName}",
     "Edit event" : "Breyta atburði",
     "Event does not exist" : "Atburður er ekki til",
-    "Duplicate" : "Tvítaka",
     "Delete this occurrence" : "Eyða þessu tilviki",
     "Delete this and all future" : "Eyða þessu og framtíðar tilvikum",
     "All day" : "Heilsdagsviðburður",
+    "Add Talk conversation" : "Bæta við samtali á spjallrás",
     "Managing shared access" : "Sýsla með sameiginlegan aðgang",
     "Deny access" : "Hafna aðgangi",
     "Invite" : "Bjóða",
@@ -552,19 +547,21 @@ OC.L10N.register(
     "Error while sharing file with user" : "Villa við deilingu skráar með notanda",
     "Attachment {fileName} already exists!" : "Viðhengið {fileName} er þegar til staðar!",
     "An error occurred during getting file information" : "Villa kom upp við að sækja upplýsingar um skrá",
-    "Talk conversation for event" : "Samtal fyrir atburð",
     "An error occurred, unable to delete the calendar." : "Villa kom upp, gat ekki eytt dagatalinu.",
     "Imported {filename}" : "Flutti inn {filename}",
     "This is an event reminder." : "Þetta er áminning vegna atburðar.",
     "Error while parsing a PROPFIND error" : "Villa við þáttun á PROPFIND-villu",
     "Appointment not found" : "Stefnumót fannst ekki",
     "User not found" : "Notandi fannst ekki",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "Falinn",
     "can edit" : "getur breytt",
     "Calendar name …" : "Heiti dagatals …",
     "Default attachments location" : "Sjálfgefin staðsetning viðhengja",
     "Automatic ({detected})" : "Sjálfvirkt ({detected})",
     "Shortcut overview" : "Yfirlit flýtilykla",
+    "CalDAV link copied to clipboard." : "CalDAV-tengill afritaður á klippispjald.",
+    "CalDAV link could not be copied to clipboard." : "Ekki var hægt að afrita CalDAV-tengil á klippispjald.",
     "Enable birthday calendar" : "Virkja fæðingardagatal",
     "Show tasks in calendar" : "Sýna verkefni í dagatali",
     "Enable simplified editor" : "Virkja einfaldaðan ritil",
@@ -572,10 +569,15 @@ OC.L10N.register(
     "Show weekends" : "Sýna helgar",
     "Show week numbers" : "Sýna vikunúmer",
     "Time increments" : "Tímaþrep",
+    "Default calendar for incoming invitations" : "Sjálfgefið dagatal fyrir boð sem berast",
     "Copy primary CalDAV address" : "Afrita aðal-CalDAV-vistfang",
+    "Copy iOS/macOS CalDAV address" : "Afrita iOS/macOS CalDAV-vistfang ",
     "Personal availability settings" : "Persónulegar stillingar varðandi hvenær til taks",
     "Show keyboard shortcuts" : "Birta flýtivísanir á lyklaborði",
     "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} boðið, {confirmedCount} staðfestir",
+    "Successfully appended link to talk room to location." : "Tókst að bæta tengli á spjallsvæði við staðsetningu.",
+    "Successfully appended link to talk room to description." : "Tókst að bæta tengli á spjallsvæði við lýsingu.",
+    "Error creating Talk room" : "Villa við að búa til spjallsvæði.",
     "_%n more guest_::_%n more guests_" : ["%n gestur til viðbótar","%n gestir til viðbótar"],
     "The visibility of this event in shared calendars." : "Sýnileiki þessa atburðar í sameiginlegum dagatölum"
 },
