@@ -61,6 +61,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "예약 링크를 클립보드에 복사하지 못했습니다",
     "Preview" : "미리 보기",
     "Copy link" : "링크 복사",
+    "Duplicate" : "복제",
     "Edit" : "수정",
     "Delete" : "삭제",
     "Appointment schedules" : "약속 일정",
@@ -201,6 +202,7 @@ OC.L10N.register(
     "Create appointment schedule" : "약속 일정 생성",
     "Edit appointment schedule" : "약속 일정 수정",
     "Update" : "업데이트",
+    "(copy)" : "(복사)",
     "Appointment name" : "약속 이름",
     "Location" : "위치",
     "Create a Talk room" : "대화방 만들기",
@@ -297,6 +299,7 @@ OC.L10N.register(
     "Accept" : "수락",
     "Decline" : "거절",
     "Tentative" : "예정됨",
+    "Copied to clipboard" : "클립보드로 복사됨",
     "No attendees yet" : "아직 참석자가 없습니다.",
     "Attendees" : "참석자",
     "Remove group" : "그룹 지우기",
@@ -402,7 +405,6 @@ OC.L10N.register(
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "설정된 시간대 ({timezoneId}) 을(를) 찾을 수 없습니다. UTC로 설정됩니다.\n설정에서 시간대를 변경하고 이 문제를 보고해 주십시오.",
     "Edit event" : "일정 편집",
     "Event does not exist" : "일정이 존재하지 않음",
-    "Duplicate" : "복제",
     "Delete this occurrence" : "이 일정 삭제",
     "Delete this and all future" : "이후 모든 일정 삭제",
     "All day" : "하루 종일",
@@ -414,6 +416,7 @@ OC.L10N.register(
     "Title" : "제목",
     "30 min" : "30분",
     "Participants" : "참가자",
+    "Thank you for your response!" : "답변해 주셔서 감사합니다!",
     "Submit" : "제출",
     "Subscribe to {name}" : "{name} 구독",
     "Export {name}" : "{name} 내보내기",
