@@ -18,7 +18,6 @@ OC.L10N.register(
     "%1$s with %2$s" : "%1$s su %2$s",
     "Calendar" : "Kalendorius",
     "Appointments" : "Susitikimai",
-    "%1$s - %2$s" : "%1$s – %2$s",
     "Confirm" : "Patvirtinti",
     "Description:" : "Aprašas:",
     "This confirmation link expires in %s hours." : "Ši patvirtinimo nuoroda baigia galioti po %s val.",
@@ -161,14 +160,11 @@ OC.L10N.register(
     "Calendar settings" : "Kalendoriaus nustatymai",
     "No reminder" : "Jokio priminimo",
     "Failed to save default calendar" : "Nepavyko įrašyti numatytojo kalendoriaus",
-    "CalDAV link copied to clipboard." : "CalDAV nuoroda nukopijuota į iškarpinę.",
-    "CalDAV link could not be copied to clipboard." : "Nepavyko nukopijuoti CalDAV nuorodą į iškarpinę.",
     "General" : "Bendra",
-    "Copy iOS/macOS CalDAV address" : "Kopijuoti iOS/macOS CalDAV adresą",
     "Appearance" : "Išvaizda",
     "Editing" : "Taisymas",
     "Default reminder" : "Numatytasis priminimas",
-    "Keyboard shortcuts" : "Spartieji klavišai",
+    "Files" : "Failai",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minutė","{duration} minutės","{duration} minučių","{duration} minutė"],
     "0 minutes" : "0 minučių",
     "_{duration} hour_::_{duration} hours_" : ["{duration} valanda","{duration} valandos","{duration} valandų","{duration} valanda"],
@@ -180,6 +176,7 @@ OC.L10N.register(
     "Public – shown on the profile page" : "Viešas – rodomas profilio puslapyje",
     "Private – only accessible via secret link" : "Privatus – pasiekiamas tik per slaptą nuorodą",
     "Update" : "Atnaujinti",
+    "(copy)" : "(kopija)",
     "Location" : "Vieta",
     "Description" : "Aprašas",
     "Visibility" : "Matomumas",
@@ -246,9 +243,8 @@ OC.L10N.register(
     "Accept" : "Priimti",
     "Decline" : "Atmesti",
     "Tentative" : "Preliminarus",
+    "Copied to clipboard" : "Nukopijuota į iškarpinę",
     "No attendees yet" : "Kol kas kviestinių nėra",
-    "Successfully appended link to talk room to description." : "Pokalbių kambario nuoroda sėkmingai pridėta į aprašą.",
-    "Error creating Talk room" : "Klaida sukuriant pokalbių kambarį",
     "Attendees" : "Kviestiniai",
     "Remove group" : "Šalinti grupę",
     "Remove attendee" : "Šalinti kviestinį",
@@ -434,12 +430,15 @@ OC.L10N.register(
     "This is an event reminder." : "Tai priminimas apie įvykį.",
     "Appointment not found" : "Susitikimas nerastas",
     "User not found" : "Naudotojas nerastas",
+    "%1$s - %2$s" : "%1$s – %2$s",
     "Hidden" : "Paslėpta",
     "can edit" : "gali redaguoti",
     "Calendar name …" : "Kalendoriaus pavadinimas…",
     "Default attachments location" : "Numatytoji priedų vieta",
     "Automatic ({detected})" : "Automatinė ({detected})",
     "Shortcut overview" : "Nuorodų apžvalga",
+    "CalDAV link copied to clipboard." : "CalDAV nuoroda nukopijuota į iškarpinę.",
+    "CalDAV link could not be copied to clipboard." : "Nepavyko nukopijuoti CalDAV nuorodą į iškarpinę.",
     "Enable birthday calendar" : "Įjungti gimtadienių kalendorių",
     "Show tasks in calendar" : "Rodyti užduotis kalendoriuje",
     "Enable simplified editor" : "Įjungti supaprastintą redaktorių",
@@ -447,8 +446,11 @@ OC.L10N.register(
     "Show weekends" : "Rodyti savaitgalius",
     "Show week numbers" : "Rodyti savaičių numerius",
     "Copy primary CalDAV address" : "Kopijuoti pirminį CalDAV adresą",
+    "Copy iOS/macOS CalDAV address" : "Kopijuoti iOS/macOS CalDAV adresą",
     "Personal availability settings" : "Asmeninio pasiekiamumo nustatymai",
     "Show keyboard shortcuts" : "Rodyti sparčiuosius klavišus",
+    "Successfully appended link to talk room to description." : "Pokalbių kambario nuoroda sėkmingai pridėta į aprašą.",
+    "Error creating Talk room" : "Klaida sukuriant pokalbių kambarį",
     "The visibility of this event in shared calendars." : "Šio įvykio matomumas bendrinamuose kalendoriuose."
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
