@@ -22,7 +22,8 @@ OC.L10N.register(
     "Appointments" : "Möten",
     "Schedule appointment \"%s\"" : "Schemalägg möte ”%s”",
     "Schedule an appointment" : "Schemalägg ett möte",
-    "%1$s - %2$s" : "%1$s - %2$s",
+    "Requestor Comments:" : "Begärarens kommentarer:",
+    "Appointment Description:" : "Mötesbeskrivning:",
     "Prepare for %s" : "Förberedelse inför %s",
     "Follow up for %s" : "Uppföljning av %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Ditt möte \"%s\" med %s behöver bekräftas",
@@ -48,10 +49,12 @@ OC.L10N.register(
     "Dear %s, a proposed meeting has been updated" : "Hej %s, ett föreslaget möte har uppdaterats",
     "Dear %s, a proposed meeting has been cancelled" : "Hej %s, ett föreslaget möte har avbokats",
     "Location:" : "Ort:",
+    "%1$s minutes" : "%1$s minuter",
     "Duration:" : "Varaktighet:",
     "%1$s from %2$s to %3$s" : "%1$s från %2$s till %3$s",
     "Dates:" : "Datum:",
     "Respond" : "Svara",
+    "[Proposed] %1$s" : "[Föreslagen] %1$s",
     "A Calendar app for Nextcloud" : "En kalender-app för Nextcloud",
     "Previous day" : "Föregående dag",
     "Previous week" : "Föregående vecka",
@@ -73,6 +76,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Möteslänk kunde ej kopieras till urklipp",
     "Preview" : "Förhandsvisa",
     "Copy link" : "Kopiera länk",
+    "Duplicate" : "Duplicera",
     "Edit" : "Redigera",
     "Delete" : "Ta bort",
     "Appointment schedules" : "Mötesscheman",
@@ -209,14 +213,12 @@ OC.L10N.register(
     "At event start" : "Vid händelsens start",
     "No reminder" : "Ingen påminnelse",
     "Failed to save default calendar" : "Det gick inte att spara standardkalendern",
-    "CalDAV link copied to clipboard." : "CalDAV-länk kopierad till urklipp.",
-    "CalDAV link could not be copied to clipboard." : "CalDAV-länk kunde inte kopieras till urklipp.",
     "General" : "Allmänt",
     "Availability settings" : "Inställningar för tillgänglighet",
     "CalDAV" : "CalDAV",
     "Access Nextcloud calendars from other apps and devices" : "Åtkomst till Nextcloud-kalendrar från andra appar och enheter",
     "CalDAV URL" : "CalDAV URL",
-    "Copy iOS/macOS CalDAV address" : "Kopiera iOS/macOS CalDAV-adress",
+    "Server Address for iOS and macOS" : "Serveradress för iOS och macOS",
     "Appearance" : "Utseende",
     "Birthday calendar" : "Födelsedagskalender",
     "Tasks in calendar" : "Uppgifter i kalendern",
@@ -225,11 +227,10 @@ OC.L10N.register(
     "Limit number of events shown in Month view" : "Begränsa antalet händelser som visas i månadsvyn",
     "Density in Day and Week View" : "Täthet i dag- och vecko­vy",
     "Editing" : "Ändrar",
+    "Default reminder" : "Standardpåminnelse",
     "Simple event editor" : "Enkel händelseredigerare",
     "\"More details\" opens the detailed editor" : "”Mer information” öppnar den detaljerade redigeraren",
-    "Default calendar for incoming invitations" : "Standardkalender för inkommande inbjudningar",
-    "Default reminder" : "Standardpåminnelse",
-    "Keyboard shortcuts" : "Tangentbordsgenvägar",
+    "Files" : "Filer",
     "Appointment schedule successfully created" : "Mötesschema skapat",
     "Appointment schedule successfully updated" : "Mötesschema uppdaterat",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minuter"],
@@ -246,6 +247,7 @@ OC.L10N.register(
     "Create appointment schedule" : "Skapa mötesschema",
     "Edit appointment schedule" : "Redigera mötesschema",
     "Update" : "Uppdatera",
+    "(copy)" : "(kopia)",
     "Appointment name" : "Namn på möte",
     "Location" : "Plats",
     "Create a Talk room" : "Skapa ett rum i Talk",
@@ -289,13 +291,16 @@ OC.L10N.register(
     "Successfully added Talk conversation link to location." : "Länk till Talk-konversation har lagts till på platsen.",
     "Successfully added Talk conversation link to description." : "Länk till Talk-konversation har lagts till i beskrivningen.",
     "Failed to apply Talk room." : "Kunde inte tillämpa rum i Talk.",
+    "Talk conversation for event" : "Talk-konversation för händelse",
     "Error creating Talk conversation" : "Kunde inte skapa Talk-konversation",
     "Select a Talk Room" : "Välj ett rum i Talk",
-    "Add Talk conversation" : "Lägg till Talk-konversation",
     "Fetching Talk rooms…" : "Hämtar Talk-rum...",
     "No Talk room available" : "Inget Talk-rum tillgängligt",
-    "Create a new public conversation" : "Skapa en ny offentlig konversation",
+    "Select existing conversation" : "Välj befintlig konversation",
     "Select conversation" : "Välj konversation",
+    "Or create a new conversation" : "Eller skapa en ny konversation",
+    "Create public conversation" : "Skapa offentlig konversation",
+    "Create private conversation" : "Skapa privat konversation",
     "on" : "den",
     "at" : "kl",
     "before at" : "innan",
@@ -318,7 +323,7 @@ OC.L10N.register(
     "Choose a file to share as a link" : "Välj en fil att dela som länk",
     "Attachment {name} already exist!" : "Bilagan {name} finns redan!",
     "Could not upload attachment(s)" : "Kunde inte ladda upp bilagor",
-    "You are about to download a file. Please check the file name before opening it. Are you sure to proceed?" : "Du håller på att ladda ner en fil. Kontrollera filnamnet innan du öppnar den. Är du säker på att du vill fortsätta?",
+    "You are about to navigate to {link}. Are you sure to proceed?" : "Du är på väg att navigera till {link}. Är du säker på att du vill fortsätta?",
     "You are about to navigate to {host}. Are you sure to proceed? Link: {link}" : "Du är på väg att navigera till {host}. Är du säker på att du vill fortsätta? Länk: {link}",
     "Proceed" : "Fortsätt",
     "No attachments" : "Inga bilagor",
@@ -377,14 +382,12 @@ OC.L10N.register(
     "Accept" : "Acceptera",
     "Decline" : "Avböj",
     "Tentative" : "Preliminärt",
+    "Copied to clipboard" : "Kopierat till urklipp",
     "No attendees yet" : "Inga deltagare än",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} inbjudna, {confirmedCount} bekräftade",
+    "{confirmedCount} confirmed, {waitingCount} awaiting response" : "{confirmedCount} bekräftade, {waitingCount} väntar på svar",
     "Please add at least one attendee to use the \"Find a time\" feature." : "Lägg till minst en deltagare för att använda funktionen “Hitta en tid”.",
-    "Successfully appended link to talk room to location." : "Länk till rum i Talk tillagd i plats.",
-    "Successfully appended link to talk room to description." : "Länk till rum i Talk tillagd i beskrivningen.",
-    "Error creating Talk room" : "Kunde inte skapa rum i Talk",
     "Attendees" : "Deltagare",
-    "_%n more guest_::_%n more guests_" : ["%n gäst till","%n gäster till"],
+    "_%n more attendee_::_%n more attendees_" : ["%n ytterligare deltagare","%n ytterligare deltagare"],
     "Remove group" : "Ta bort grupp",
     "Remove attendee" : "Ta bort deltagaren",
     "Request reply" : "Begär svar",
@@ -515,11 +518,11 @@ OC.L10N.register(
     "Discard event" : "Avbryt händelse",
     "Edit event" : "Redigera händelse",
     "Event does not exist" : "Händelsen existerar inte",
-    "Duplicate" : "Duplicera",
     "Delete this occurrence" : "Ta bort denna förekomst",
     "Delete this and all future" : "Ta bort denna och alla kommande",
     "All day" : "Heldag",
     "Modifications wont get propagated to the organizer and other attendees" : "Ändringar kommer inte att skickas till organisatören eller andra deltagare",
+    "Add Talk conversation" : "Lägg till Talk-konversation",
     "Managing shared access" : "Hantering av delad åtkomst",
     "Deny access" : "Neka åtkomst",
     "Invite" : "Bjud in",
@@ -668,7 +671,6 @@ OC.L10N.register(
     "Attachment {fileName} added!" : "Bilaga {fileName} tillagd!",
     "An error occurred during uploading file {fileName}" : "Ett fel uppstod vid uppladdning av filen {fileName}",
     "An error occurred during getting file information" : "Ett fel uppstod vid hämtning av filinformation",
-    "Talk conversation for event" : "Talk-konversation för händelse",
     "Talk conversation for proposal" : "Talk-konversation för förslaget",
     "An error occurred, unable to delete the calendar." : "Ett fel inträffade, kunde inte radera kalendern.",
     "Imported {filename}" : "Importerad {filename}",
@@ -676,12 +678,15 @@ OC.L10N.register(
     "Error while parsing a PROPFIND error" : "Fel vid analys av ett PROPFIND-fel",
     "Appointment not found" : "Mötet hittades inte",
     "User not found" : "Användaren hittades inte",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "Gömd",
     "can edit" : "kan redigera",
     "Calendar name …" : "Kalendernamn ...",
     "Default attachments location" : "Standardplats för bilagor",
     "Automatic ({detected})" : "Automatisk ({detected})",
     "Shortcut overview" : "Översikt av genvägar",
+    "CalDAV link copied to clipboard." : "CalDAV-länk kopierad till urklipp.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV-länk kunde inte kopieras till urklipp.",
     "Enable birthday calendar" : "Aktivera födelsedagskalender",
     "Show tasks in calendar" : "Visa uppgifter i kalendern",
     "Enable simplified editor" : "Aktivera förenklad redigerare",
@@ -689,13 +694,17 @@ OC.L10N.register(
     "Show weekends" : "Visa helger",
     "Show week numbers" : "Visa veckonummer",
     "Time increments" : "Tidsintervall",
+    "Default calendar for incoming invitations" : "Standardkalender för inkommande inbjudningar",
     "Copy primary CalDAV address" : "Kopiera primär CalDAV-adress",
+    "Copy iOS/macOS CalDAV address" : "Kopiera iOS/macOS CalDAV-adress",
     "Personal availability settings" : "Dina tillgänglighetsinställningar",
     "Show keyboard shortcuts" : "Visa tangentbordsgenvägar",
-    "The visibility of this event in shared calendars." : "Synligheten för denna händelse i delade kalendrar.",
-    "View options" : "Visningsalternativ",
-    "Limit number of events shown in month view" : "Begränsa antalet händelser som visas i månadsvyn",
-    "Time division in day and week view" : "Tidsindelning i dag- och vecko­vy",
-    "Enable simple editor" : "Aktivera enkel redigerare"
+    "Create a new public conversation" : "Skapa en ny offentlig konversation",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} inbjudna, {confirmedCount} bekräftade",
+    "Successfully appended link to talk room to location." : "Länk till rum i Talk tillagd i plats.",
+    "Successfully appended link to talk room to description." : "Länk till rum i Talk tillagd i beskrivningen.",
+    "Error creating Talk room" : "Kunde inte skapa rum i Talk",
+    "_%n more guest_::_%n more guests_" : ["%n gäst till","%n gäster till"],
+    "The visibility of this event in shared calendars." : "Synligheten för denna händelse i delade kalendrar."
 },
 "nplurals=2; plural=(n != 1);");
