@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "Các lịch hẹn ",
     "Schedule appointment \"%s\"" : "Lên lịch lịch hẹn \"%s\"",
     "Schedule an appointment" : "Lên lịch một lịch hẹn",
-    "%1$s - %2$s" : "%1$s-%2$s",
     "Prepare for %s" : "Chuản bị cho %s",
     "Follow up for %s" : "Diễn tiến cho %s",
     "Dear %s, please confirm your booking" : "%s thân ái, vui lòng xác nhận lịch đặt hẹn của bạn",
@@ -113,7 +112,6 @@ OC.L10N.register(
     "Delete share link" : "Xóa liên kết chia sẻ",
     "Deleting share link …" : "Đang xóa liên kết chia sẻ  ...",
     "An error occurred, unable to change the permission of the share." : "Một lỗi đã diễn ra, không thể thay đổi quyền hạn chia sẻ",
-    "can edit" : "có thể chỉnh sửa",
     "Unshare with {displayName}" : "Gỡ chia sẻ với {displayName}",
     "Share with users or groups" : "Chia sẽ với người dùng hoặc nhóm",
     "No users or groups" : "Không có người dùng hay nhóm",
@@ -126,6 +124,7 @@ OC.L10N.register(
     "Calendar to import into" : "Lịch để nhập vào",
     "Cancel" : "Hủy",
     "_Import calendar_::_Import calendars_" : ["Nhập lịch"],
+    "Attachments folder" : "Thư mục đính kèm",
     "{filename} could not be parsed" : "{filename} không thể được phân tách",
     "No valid files found, aborting import" : "Không có tệp khả dụng được tìm thấy, đang hủy quá trình nhập",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n sự kiện đã được nhập vào thành công"],
@@ -151,19 +150,11 @@ OC.L10N.register(
     "Delete edited event" : "Xoá sự kiện được chỉnh sửa",
     "or" : "hoặc",
     "No reminder" : "Không có nhắc hẹn",
-    "CalDAV link copied to clipboard." : "Liên kết CalDAV đã được sao chép vào bảng tạm",
-    "CalDAV link could not be copied to clipboard." : "Liên kết CalDAV không thể được sao chép vào bảng tạm.",
     "General" : "Cài đặt chung",
-    "Personal availability settings" : "Thiết lập lịch trống cá nhân",
-    "Copy primary CalDAV address" : "Sao chép địa chỉ CalDAV chính",
-    "Copy iOS/macOS CalDAV address" : "Sao chép địa chỉ CalDAV cho iOS/macOC",
-    "Enable birthday calendar" : "Bật lịch sinh nhật",
-    "Show tasks in calendar" : "Cho thấy nhiệm vụ trong lịch",
-    "Show weekends" : "Cho thấy ngày cuối tuần",
-    "Show week numbers" : "Hiển thị số tuần",
+    "Appearance" : "Giao diện",
     "Editing" : "Chỉnh sửa",
     "Default reminder" : "Nhác hẹn mặc định",
-    "Keyboard shortcuts" : "Phím tắt",
+    "Files" : "Tệp Tin",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} phút"],
     "0 minutes" : "0 phút",
     "_{duration} hour_::_{duration} hours_" : ["{duration} giờ"],
@@ -175,6 +166,7 @@ OC.L10N.register(
     "Public – shown on the profile page" : "Công cộng - Được hiển thị công khai trên trang thông tin cá nhân",
     "Private – only accessible via secret link" : "Riêng tư - Chỉ có thể truy cập thông qua liên kết bí mật",
     "Update" : "Cập nhật",
+    "(copy)" : "(sao chép)",
     "Location" : "Vị trí",
     "Description" : "Mô tả",
     "Visibility" : "Hiển thị",
@@ -250,9 +242,8 @@ OC.L10N.register(
     "Accept" : "Đồng ý",
     "Decline" : "Từ chối",
     "Tentative" : "Chưa chắc chắn",
+    "Copied to clipboard" : "Đã sao chép vào bộ nhớ tạm",
     "No attendees yet" : "Chưa có giờ tham gia",
-    "Successfully appended link to talk room to description." : "Liên kết đã được thêm thành công vào mô tả trong phòng trò chuyện ",
-    "Error creating Talk room" : "Có lõi xảy ra khi tạo phòng Trò chuyện",
     "Attendees" : "Người tham gia",
     "Remove group" : "Xóa nhóm",
     "Remove attendee" : "Gỡ bỏ người tham gia",
@@ -423,7 +414,6 @@ OC.L10N.register(
     "When shared show full event" : "Khi được chia sẻ thì hiển thị đầy đủ sự kiện",
     "When shared show only busy" : "Khi được chia sẻ thì chỉ hiển thị đang bận",
     "When shared hide this event" : "Khi được chia sẻ thì ẩn sự kiện này đi",
-    "The visibility of this event in shared calendars." : "Khả năng nhìn thấy của sự kiện này trong các lịch được chia sẻ",
     "Add a location" : "Thêm vào một địa điểm",
     "Status" : "Trạng thái",
     "Confirmed" : "Đã xác nhận",
@@ -442,11 +432,25 @@ OC.L10N.register(
     "Imported {filename}" : " {filename} đã được nhập",
     "Appointment not found" : "Không tìm thấy cuộc hẹn",
     "User not found" : "Không tìm thấy người dùng",
+    "%1$s - %2$s" : "%1$s-%2$s",
     "Hidden" : "Ẩn",
+    "can edit" : "có thể chỉnh sửa",
     "Automatic ({detected})" : " ({detected}) tự động",
     "Shortcut overview" : "Bản xem trước của lối tắt",
+    "CalDAV link copied to clipboard." : "Liên kết CalDAV đã được sao chép vào bảng tạm",
+    "CalDAV link could not be copied to clipboard." : "Liên kết CalDAV không thể được sao chép vào bảng tạm.",
+    "Enable birthday calendar" : "Bật lịch sinh nhật",
+    "Show tasks in calendar" : "Cho thấy nhiệm vụ trong lịch",
     "Enable simplified editor" : "Bật chỉnh sửa đơn giản",
+    "Show weekends" : "Cho thấy ngày cuối tuần",
+    "Show week numbers" : "Hiển thị số tuần",
     "Time increments" : "Mức tăng thời gian",
-    "Show keyboard shortcuts" : "Hiển thị các phím tắt"
+    "Copy primary CalDAV address" : "Sao chép địa chỉ CalDAV chính",
+    "Copy iOS/macOS CalDAV address" : "Sao chép địa chỉ CalDAV cho iOS/macOC",
+    "Personal availability settings" : "Thiết lập lịch trống cá nhân",
+    "Show keyboard shortcuts" : "Hiển thị các phím tắt",
+    "Successfully appended link to talk room to description." : "Liên kết đã được thêm thành công vào mô tả trong phòng trò chuyện ",
+    "Error creating Talk room" : "Có lõi xảy ra khi tạo phòng Trò chuyện",
+    "The visibility of this event in shared calendars." : "Khả năng nhìn thấy của sự kiện này trong các lịch được chia sẻ"
 },
 "nplurals=1; plural=0;");
